
**********************************************************************
* This do file replicates Figure 1 & Appendix Tables A1-A4 
*			& calculates patent counts in Appendix Tables A5, A6, & A8
**********************************************************************

* David Dorn & Pian Shu, January 2019

* Input files:
* - ../patent-match/cw_patent_compustat_adhps.dta: patent-level, crosswalk between corporate patents and Compustat firms across all application years
* - ../dta/pat5yr_adhps.dta: patent-level, corporate patents with US inventors for 5 application years (75/83/91/99/07)
* - ../dta/pat5yr_adhps_foreign.dta: patent-level, corporate patents with foreign inventors for 5 application years (75/83/91/99/07)
* - ../dta/pat5yr_adhps_noncorp.dta: patent-level, non-corporate patents for 5 application years (75/83/91/99/07)
* - ../dta/figure1a_pat_imports: year-level, count of patents and value of US imports from China
* - ../dta/figure1b_imports: sector-level, growth in import penetration
* - ../dta/tableA1_IBM: assignee names matched to Compustat
* - ../dta/tableA3_compustatinfo.dta: sample-level, aggregate Compustat stats
* - ../dta/firm_9107_segm_data_final.dta: firm data with import shocks defined based on industry segment sales

* Administrative Commands
cap log close
set more off
clear

log using ../log/summarystats.log, text replace

*******************************************************************
* Figure 1
*******************************************************************

*** Panel A -  Number of Patents by Application Year ***

use ../patent-match/cw_patent_compustat_adhps.dta, clear
keep if appyear>=1975 & appyear<=2007
keep if usinv
rename usinv corpasg_usinv_compustat

* convert to year-level
collapse (sum) corpasg_usinv_compustat, by(appyear)
* add data on imports
rename appyear year
merge 1:1 year using ../dta/figure1a_pat_imports, assert(1 3) nogenerate

foreach var of varlist usinv corpasg_usinv corpasg_usinv_compustat {
	replace `var' = `var' / 1000
}

* graph 
twoway  (line usinv year, yaxis(1) lcolor(navy) lpattern(dash_dot) lwidth(medthick)) ///
		(line corpasg_usinv year, yaxis(1) lcolor(cranberry) lpattern(longdash_dot) lwidth(medthick)) ///
		(line corpasg_usinv_compustat year, yaxis(1) lcolor(black) lpattern(solid) lwidth(medthick)) ///
		(line imports year, yaxis(2) lcolor(green) lpattern(dash) lwidth(medthick)), ///
		legend(size(small) rows(4) label(1 "All Patents with US Inventors") label(2 "Corporate Patents with US Inventors") ///
			label(3 "Corporate Patents with US Inventors & Matched to Compustat") label(4 "Total US Imports from China")) ///
		ytitle("Number of Patents" "(in thousands)", size (small) height(8)) ytitle("Total US Imports from China" "(in billions of 2007 USD)", size (small) axis(2) height(6)) ylabel(0(25)100) ///
		xlabel(1975(8)2007) xtitle("Year of Patent Application", size (small))
graph export ../tabfig/figure1a.pdf, replace
		
*** Panel B - Growth in Sectoral Patenting and Import Penetration from China ***

use ../dta/pat5yr_adhps.dta, clear
keep if mfg 
gen count = 1
collapse (sum) count, by(sector appyear)
reshape wide count, i(sector) j(appyear)
gen lnchg_7591 = ln(count1991) - ln(count1975)
gen lnchg_9107 = ln(count2007) - ln(count1991)

* add data on imports
drop if sector == "Non-Mfg"
merge 1:1 sector using ../dta/figure1b_imports, assert(3) nogenerate

* graph
twoway (scatter lnchg_7591 d_import_usch_pd_long [w=count1975], ///
		msymbol(Oh) msize(*3.9) mlcolor(navy) xlabel(0(20)70) ylabel(-0.7(0.5)1.5) ///
		ytitle("Log Change in Patents 1975-1991 & 1991-2007", size (small) margin(0 3 0 0)) ///
		xtitle("Growth of Import Penetration 1991-2007", size (small) margin(0 0 3 2)) ) ///
		(scatter lnchg_9107 d_import_usch_pd_long, msymbol(none) mlabel(sector) mlabcolor(cranberry) mlabposition(0)) ///
		(scatter lnchg_9107 d_import_usch_pd_long [w=count1991], ///
		msymbol(Oh) msize(*6.4) mlcolor(cranberry) xlabel(0(20)70) legend(order (1 3) ///
		label(1 "Corporate Patents with US Inventors" "Growth 1975-1991") ///
		label(3 "Corporate Patents with US Inventors" "Growth 1991-2007") size(small)))
graph export ../tabfig/figure1b.pdf, replace
		

*******************************************************************
* Table A1 - Patents Matched to IBM
*******************************************************************

use ../patent-match/cw_patent_compustat_adhps.dta, clear
keep if gvkey=="006066"
foreach x in "ROLM" "ALPHABLOX" "TELELOGIC" "ARMONK" "LOTUS" "MAKOSCH" {
	drop if strpos(assignee, "`x'") > 0 // drop subsidiaries
}
* Compare to 
gen count = 1
gen count_by2006=gyear<=2006
collapse (sum) count count_by2006, by (assignee_clean)
gen group = "1-common spelling, appear before 2006" if count>=2 & count_by2006>0
replace group = "2-common spelling, appear after 2006" if count>=2 & count_by2006==0
assert count==1 if group == ""
count if group=="" // misc uncommon spellings
tab group
drop count_by2006
* Matching
merge 1:1 assignee_clean using ../dta/tableA1_IBM, assert(3) nogenerate
count if group=="" & flag_noPDPmatch == "" // uncommon spellings matched by pdp
count if group=="" & match_source == "2-web" // uncommon spellings matched by web
drop if group==""
order group, first
gsort group -count match_source assignee_clean
replace match_source = "name" if match_source=="1-name"
replace match_source = "web" if match_source=="2-web"
replace match_source = "nber-pdp" if match_source=="3-nber-pdp"
export excel using ../tabfig/tableA1.xlsx, firstrow(var) replace

*******************************************************************
* Table A2 - Patent Matching Descriptives
*******************************************************************

use ../dta/pat5yr_adhps.dta, clear

* Column 1: Number of corporate patents with US inventors
tab appyear

* Columns 2 & 3: Number & Share Matched by ADHPS
tab appyear if matched_ADHPS
tabstat matched_ADHPS, by(appyear)

* Columns 4 & 5: Number & Share Matched by NBER-PDP
tab appyear if matched_pdp
tabstat matched_pdp, by(appyear)

* Columns 6 & 7: Number & Share Matched by ADHPS Web
tab appyear if webmatch
tabstat webmatch, by(appyear)

* Columns 8 - 11: Sequential Steps
gen match_name = match_source == "name"
gen match_web = match_source == "web"
gen match_pdp = match_source == "nber-pdp"
gen match_manual = match_source == "manual"

tabstat match_name match_web match_pdp match_manual if matched_ADHPS, by(appyear)



*******************************************************************
* Table A3 - Compustat Firm-Level Descriptives
*******************************************************************
 
use ../dta/pat5yr_adhps.dta, clear
keep if valid_sic
merge 1:1 patent using ../patent-match/cw_patent_compustat_adhps, assert(2 3) keep(3) keepusing(gvkey) nogenerate

* Count number of patenting firms
* all years
preserve
egen count_firm1 = nvals(gvkey)
egen count_firm2 = nvals(gvkey) if mfg==1
collapse (firstnm) count_firm1 count_firm2
duplicates drop
gen year = 9999
reshape long count_firm, i(year) j(sample)
tempfile temp_all
drop year
save `temp_all', replace
restore
* by application year
egen count_appyear1=nvals(gvkey),by(appyear)
egen count_appyear2=nvals(gvkey) if mfg==1, by(appyear)
collapse (firstnm) count_appyear*, by(appyear)
reshape long count_appyear, i(appyear) j(sample)
* convert data to sample-level data
reshape wide count_appyear, i(sample) j(appyear)
merge 1:1 sample using `temp_all', nogenerate
tostring sample, replace
replace sample = "in-sample firms" if sample == "1"
replace sample = "in-sample mfg firms" if sample == "2"
order sample count_firm count_appyear*

* Add Compustat data
merge 1:1 sample using ../dta/tableA3_compustatinfo, assert(2 3) nogenerate

* Column 1-I: In-sample Firms, All Sectors
 **Count
list count_firm count_appyear* if sample == "in-sample firms"
 **Info in 1991
list count_nonmiss91 ussale_avg91 sale_avg91 emp_avg91 icapt_avg91 xrd_avg91 if sample == "in-sample firms"

* Column 1-II: In-sample Firms, Mfg Sectors
 **Count
list count_firm count_appyear* if sample == "in-sample mfg firms"
 **Info in 1991
list count_nonmiss91 ussale_avg91 sale_avg91 emp_avg91 icapt_avg91 xrd_avg91 if sample == "in-sample mfg firms"

* Column 2-I: All Compustat Firms, All Sectors
list count_firm count_nonmiss91 ussale_avg91 sale_avg91 emp_avg91 icapt_avg91 xrd_avg91 if sample == "all firms"

* Column 2-II: All Compustat Firms, Mfg Sectors
list count_firm count_nonmiss91 ussale_avg91 sale_avg91 emp_avg91 icapt_avg91 xrd_avg91 if sample == "all mfg firms"

* Column 3-I: Contribution of In-Sample Firms to Overall Volume, All Sectors 
 **Count calculated by hand (column 1 / column 2)
 **Financial info in 1991 
list ussale_volume91 sale_volume91 emp_volume91 icapt_volume91 xrd_volume91 if sample == "in-sample firms"

* Column 3-II: Contribution of In-Sample Firms to Overall Volume, Mfg Sectors 
 **Count calculated by hand (column 1 / column 2)
 **Financial info in 1991
list ussale_volume91 sale_volume91 emp_volume91 icapt_volume91 xrd_volume91 if sample == "in-sample mfg firms"


*******************************************************************
* Table A4 - Distribution of Patents across Sectors
*******************************************************************

use ../dta/pat5yr_adhps.dta, clear
* share of mfg patents 
tabstat mfg if valid_sic, by(appyear)
* distribution across mfg sectors 
keep if mfg == 1
drop mfg_nocompchem
gen total = 1
collapse (sum) total mfg_*, by(appyear)
foreach var of varlist mfg_* {
replace `var' = `var' / total
}
drop total
order appyear mfg_chempet mfg_comp mfg_equipnocomp mfg_transport mfg_papprint mfg_metal mfg_foodtob mfg_claystone mfg_woodfurn mfg_other mfg_texappl         
export excel using ../tabfig/tableA4.xlsx, firstrow(var) replace  // table can be transposed in Excel


*******************************************************************
* Table A5 - Number of Patents used by Sample
*******************************************************************

use ../dta/pat5yr_adhps.dta, clear

* Main sample (columns 1-3)
tab sample_usinv

* Balanced sample with historical industry codes (column 4)
tab sample_histbalanced

* Balanced sample with historical industry segment codes (column 5)
use ../dta/firm_9107_segm_data_final.dta, clear
summ totpatsegct*


*******************************************************************
* Table A6 - Number of Patents used by Sample
*******************************************************************

use ../dta/pat5yr_adhps.dta, clear

* Number of patents used in regression models, columns 1-10
tab sample_g6
tab sample_excomp
tab sample_exchdrg
tab sample_noman
tab sample_nameweb
tab sample_balanced
tab sample_citewt
tab sample_xrdwt
tab sample_saleuswt
tab sample_balanced


*******************************************************************
* Table A7 - Number of Patents used by Sample
*******************************************************************

use ../dta/pat5yr_adhps.dta, clear
gen sample_noncorp=0
append using ../dta/pat5yr_adhps_noncorp.dta
gen counter=1

* All corporate patents
tab counter if sample_noncorp==0 & (appyear==1991 | appyear==1999 | appyear==2007)

* All corporate patents matched to Compustat
tab counter if sample_noncorp==0 & matched_ADHPS==1 & (appyear==1991 | appyear==1999 | appyear==2007)

* All non-corporate patents 
tab counter if sample_noncorp==1 & (appyear==1991 | appyear==1999 | appyear==2007)

* All corporate and non-corporate patents 
tab counter if (appyear==1991 | appyear==1999 | appyear==2007)


*******************************************************************
* Table A8 - Number of Patents used by Sample
*******************************************************************

use ../dta/pat5yr_adhps.dta, clear
append using ../dta/pat5yr_adhps_foreign.dta

* Number of patents used in regression models, columns 1-3
tab sample_usinv
tab sample_usfirms_usinv
tab sample_ffirms_usinv

* Number of patents used in regression models, columns 4-7
tab sample_usfirms
tab sample_usfirms_usinv
tab sample_usfirms_finv
tab sample_allfirms

clear all
log close
